# coding=utf-8
from django.core.urlresolvers import reverse
from django.http import HttpResponse, HttpResponseRedirect
from django.template import RequestContext, loader, Context
from django.template.loader_tags import ExtendsNode
from django.utils.crypto import get_random_string
from json import dumps
from django.views.decorators.csrf import csrf_exempt
from django.forms import ModelForm


def redirect(to, args=None, kwargs=None):
    try:
        url = reverse(to, args=args, kwargs=kwargs)
    except Exception:
        if args is None and kwargs is None:
            url = to
        else:
            raise
    return HttpResponseRedirect(url)


def change_block_names(template, change_dict):
    """
    This function will rename the blocks in the template from the
    dictionary. The keys in th change dict will be replaced with
    the corresponding values. This will rename the blocks in the
    extended templates only.
    """
    extend_nodes = template.nodelist.get_nodes_by_type(ExtendsNode)
    if len(extend_nodes) == 0:
        return
    extend_node = extend_nodes[0]
    blocks = extend_node.blocks
    for name, new_name in change_dict.items():
        if name in blocks:
            block_node = blocks[name]
            block_node.name = new_name
            blocks[new_name] = block_node
            del blocks[name]


def render_to_response(template, request, data=None, block_changes=None):
    """
    Renders the given template with given data and returns the HttpResponse

    @type request: django.http.HttpRequest
    @param request: The request object

    @type data: dict
    @param data: The extra variables that has to be passed to the context

    @type template: string
    @param template: The name of the template to be rendered

    @rtype: HttpResponse
    """
    context = RequestContext(request, data)
    template = loader.get_template(template)

    if isinstance(block_changes, dict):
        change_block_names(template, block_changes)

    html = template.render(context)
    return HttpResponse(html)


def render_template(request, template, data=None, url_params=None, **kwargs):
    if url_params is not None:
        if data is None:
            data = dict()

        for url_param in url_params:
            param_value = kwargs.get(url_param, '')
            if param_value != "":
                data[url_param] = param_value
    return render_to_response(template, request, data)


def download_string(contents, file_name):
    import mimetypes

    content_type = mimetypes.guess_type(file_name)[0]
    response = HttpResponse(contents, content_type=content_type)
    response['Content-Length'] = len(contents)
    response['Content-Disposition'] = "attachment; filename=%s" % file_name
    return response


def render_json(dictionary):
    string = dumps(dictionary)
    mimetype = 'application/json'
    return HttpResponse(string, mimetype=mimetype)


def render_jsonp(dictionary, callback):
    string = dumps(dictionary)
    mimetype = 'application/json'
    string = callback + '(' + string + ');'
    return HttpResponse(string, mimetype=mimetype)


def render_to_string(template, values=None, request=None):
    template = loader.get_template(template)
    if request is None:
        context = Context(values)
    else:
        context = RequestContext(request, values)
    html = template.render(context)
    return html


def is_response(response):
    return isinstance(response, HttpResponse)


def render_form(request, FormClass, RendererClass, form_template='forms.html', form_variable='form', instance=None, extra_dict=None, should_save=True):
    if issubclass(FormClass, ModelForm):
        form = FormClass(request.POST or None, request.FILES or None, instance=instance)
    else:
        form = FormClass(request.POST or None, request.FILES or None)
    if form.is_valid():
        try:
            obj = form.save(should_save)
            return obj
        except Exception:
            return form

    if extra_dict is None:
        extra_dict = {}

    extra_dict[form_variable] = RendererClass(form, request)
    return render_to_response(form_template, request, extra_dict)


@csrf_exempt
def delete_items_ajax(request, Model):
    """
    A generic view to delete items from a model using ajax.
    @param request:
    @type request: django.http.HttpRequest
    @return:
    """
    if request.is_ajax():
        values = request.POST.getlist('values[]')
        query = Model.objects.filter(pk__in=values)
        query.delete()
        return HttpResponse('true')
    return HttpResponse('false')


def bootstrap_message(
        request,
        heading,
        message,
        box_color='info',

        btn_1_text='',
        btn_1_color='',
        btn_1_url='',

        btn_2_text='',
        btn_2_color='',
        btn_2_url='',
        base_name='base.html',
):
    return render_to_response('django-helpers/twitter-bootstrap/message.html', request, {
        'message_heading': heading,
        'message': message,
        'box_color': box_color,
        'base_name': base_name,

        'btn_1_url': btn_1_url,
        'btn_1_text': btn_1_text,
        'btn_1_color': btn_1_color,

        'btn_2_url': btn_2_url,
        'btn_2_text': btn_2_text,
        'btn_2_color': btn_2_color,
    })


def bootstrap_error(
        request,
        message,
        heading='Error Occured !',
        box_color='danger',

        btn_1_text='',
        btn_1_color='',
        btn_1_url='',

        btn_2_text='',
        btn_2_color='',
        btn_2_url='',
        base_name='base.html',
):
    return bootstrap_message(
        request,
        heading,
        message,
        box_color,

        btn_1_text,
        btn_1_color,
        btn_1_url,

        btn_2_text,
        btn_2_color,
        btn_2_url,
        base_name
    )


def bootstrap_info(
        request,
        message,
        heading='Information',
        box_color='info',

        btn_1_text='',
        btn_1_color='',
        btn_1_url='',

        btn_2_text='',
        btn_2_color='',
        btn_2_url='',
        base_name='base.html',
):
    return bootstrap_message(
        request,
        heading,
        message,
        box_color,

        btn_1_text,
        btn_1_color,
        btn_1_url,

        btn_2_text,
        btn_2_color,
        btn_2_url,
        base_name
    )


def bootstrap_success_message(
        request,
        message,
        heading='Success',
        box_color='success',

        btn_1_text='',
        btn_1_color='',
        btn_1_url='',

        btn_2_text='',
        btn_2_color='',
        btn_2_url='',
        base_name='base.html',
):
    return bootstrap_message(
        request,
        heading,
        message,
        box_color,

        btn_1_text,
        btn_1_color,
        btn_1_url,

        btn_2_text,
        btn_2_color,
        btn_2_url,
        base_name
    )


def bootstrap_confirm(
        request,
        heading,
        message,
        yes_color='success',
        yes_text='Yes',
        cancel_color='danger',
        cancel_text='No',
        cancel_url='',
        box_color='info',
        base_name='base.html'):
    if request.method == 'POST':
        confirm = request.session['confirm_value']
        assert request.POST.get('confirm') == confirm, "Error"
        return request.POST.get('submit_button') == yes_text
    else:
        confirm = get_random_string(16)
        request.session['confirm_value'] = confirm
        return render_to_response('django-helpers/twitter-bootstrap/confirm.html', request, {
            'confirm_value': confirm,

            'confirm_heading': heading,
            'message': message,
            'base_name': base_name,
            'box_color': box_color,

            'yes_color': yes_color,
            'yes_text': yes_text,

            'cancel_color': cancel_color,
            'cancel_text': cancel_text,
            'cancel_url': cancel_url,
        })


from copy import deepcopy
from django.core.exceptions import ValidationError
from django.db.models import ForeignKey

from django.utils.safestring import mark_safe
from django_helpers.apps.static_manager.utils import get_js_files

from js_imports import require
from django_helpers.helpers.views import render_json


__author__ = 'ajumell'


def _error(content):
    return render_json({
        'err': True,
        'msg': str(content)
    })


def _success(content):
    return render_json({
        'err': False,
        'msg': content
    })


class XEditableMeta(type):
    def __new__(mcs, name, bases, attrs):
        from fields import BaseEditable

        new_class = type.__new__(mcs, name, bases, attrs)

        # This can be done now. Now think about a better syntax.
        fields = []
        field_names = []
        for attr_name, attr in attrs.iteritems():
            if isinstance(attr, BaseEditable):
                attr.field_name = attr_name

                if hasattr(new_class, attr_name):
                    delattr(new_class, attr_name)

                fields.append(attr)
                field_names.append(attr_name)

        new_class._fields = fields
        new_class._field_names = field_names

        return new_class


class XEditable(object):
    __metaclass__ = XEditableMeta

    has_js = True
    model = None
    _fields = None
    editable_id = None

    def __init__(self, instance=None, pk=None, is_ajax=False):
        if self.editable_id is None:
            raise

        self.is_ajax = is_ajax
        model = self.model
        if instance is not None:
            if not isinstance(instance, model):
                raise
            self.instance = instance
            self.pk = instance.pk
        else:
            self.instance = None
            self.pk = pk

        fields = self._fields
        new_fields = {}
        for field in fields:
            new_field = deepcopy(field)
            field_name = new_field.field_name
            new_field.editable = self
            new_field._load_validations_from_model()

            new_fields[field_name] = new_field
            setattr(self, field_name, new_field)

        self._fields = new_fields

    def get_instance(self):
        """
        @return: the current instance of the object.
        """
        instance = self.instance
        if instance is None:
            pk = self.pk
            if pk is None:
                raise
            instance = self.model.objects.get(pk=pk)
            self.instance = instance
        return instance

    def get_model_field_type(self, name):
        """
        @param name: name of the field
        @return: the value returned by the get_internal_type
        function of the model field.
        """
        cache_name = '_model_field_type_cache'
        if not hasattr(self, cache_name):
            setattr(self, cache_name, {})

        cache = getattr(self, cache_name)
        if name not in cache:
            field = self.get_model_field(name)
            val = field.get_internal_type()
            cache[name] = val
        else:
            val = cache[name]
        return val

    def get_model_field(self, name):
        """
        @param name: name of the field
        @return: returns the corresponding model field.
        """
        cache_name = '_model_field_cache'
        if not hasattr(self, cache_name):
            setattr(self, cache_name, {})

        cache = getattr(self, cache_name)
        if name not in cache:
            model = self.model
            val = model._meta.get_field_by_name(name)[0]
            cache[name] = val
        else:
            val = cache[name]
        return val

    def get_id(self, name):
        """
        @param name: name of the field
        @return: the auto-generated id for the field.
        """
        return "%s-%s-%s" % (self.editable_id, name, self.pk)

    def get_value(self, name):
        """
        @param name: name of the field
        @return: the python object of the field from the model instance
        """
        instance = self.get_instance()
        return getattr(instance, name, None)

    def validate(self, name, value):
        """
        Performs some basic validations. If a custom validation function
        is created for a field then it will be called.

        @param name: name of the field.
        @param value: the current python object for the field.
        @return: the cleaned value.
        """
        custom_validator = getattr(self, '%s_clean' % name, None)
        if hasattr(custom_validator, '__call__'):
            custom_validator()
        model_field = self.get_model_field(name)
        instance = self.get_instance()
        try:
            if isinstance(model_field, ForeignKey):
                _value = value.pk
            else:
                _value = value
            model_field.validate(_value, instance)
        except ValidationError, dt:
            raise Exception(', '.join(dt.messages))

        return value

    def render_field(self, name):
        field = self._fields[name]
        return field.render()

    def render_js(self):
        content = ''
        fields = self._fields
        for field_name in fields:
            field = fields[field_name]
            if field.has_rendered:
                js = field.render_js()
                if js is not None:
                    content += js
        return mark_safe(content)

    # View Functions

    def list(self, name):
        field = self._fields.get(name, None)
        if field is None:
            return _error('Server Error : Field does not exists.')
        return render_json(field.list())

    def save(self, request, name):
        field = self._fields.get(name, None)
        is_multivalued = getattr(field, 'is_multivalued', False)

        if field is None:
            return _error('Server Error : Field does not exists.')

        if is_multivalued:
            value = request.POST.getlist('value')
        else:
            value = request.POST.get('value')

        if value is None:
            # If no value came from request
            return _error('Server error : Value is None.')

        try:
            value = field.to_python(value)
            value = self.validate(name, value)
            instance = self.get_instance()
            setattr(instance, name, value)
            instance.clean()
            instance.save()
            op = field.to_string(value)
        except Exception, dt:
            return _error(dt)

        return _success(op)

    def js_files(self):
        files = require()
        fields = self._fields
        for field_name in fields:
            field = fields[field_name]
            files += get_js_files(field)
        return files


from types import StringTypes, FunctionType
from django.utils.safestring import mark_safe


def html_preprocessor(renderer):
    form = renderer.form
    before = getattr(renderer, 'html_before', None)
    after = getattr(renderer, 'html_after', None)

    if type(before) is dict:
        return

    for datas, attr in ((before, 'html_before'), (after, 'html_after')):
        if type(datas) is not dict:
            continue

        for name, data in datas.items():
            field = form.fields[name]
            html = None
            typ = type(data)

            if typ in StringTypes:
                html = data

            elif typ in (tuple, list):
                html = "\n".join(data)

            elif typ is FunctionType:
                html = data()

            setattr(field, attr, mark_safe(html))


# coding=utf-8
from django_helpers.apps.static_manager.utils import get_js_files

__author__ = 'ajumell'

import types
from django.core.exceptions import ImproperlyConfigured
from django.utils.importlib import import_module
from django.utils.safestring import mark_safe
from django_helpers.templatetags.jsmin import remove_blank_lines

from django_helpers.helpers.views import render_to_string

from preprocessors.replace_widgets import replace_widgets
from preprocessors.validation import validation_preprocessor, remote_validation_preprocessor
from preprocessors.extra_attrs import extra_widget_args, extra_widget_class_names
from exceptions import CSRFTokenMissingException, FormIDMissingException


def get_function(path):
    i = path.rfind('.')
    module, attr = path[:i], path[i + 1:]
    try:
        mod = import_module(module)
    except ImportError as e:
        raise ImproperlyConfigured('Error importing module %s: "%s"' % (module, e))
    try:
        func = getattr(mod, attr)
    except AttributeError:
        raise ImproperlyConfigured('Module "%s" does not define a "%s" callable processor' % (module, attr))
    return func


class FormRenderer(object):
    has_js = True

    # Text for the submit button
    form_submit = 'Submit'

    # If focus_first is set to True then the
    # first input element will be focused using js
    focus_first = None

    # A Unique identifier for this form
    form_id = None

    # Name of the template to be rendered.
    template = 'form-renderer/form.html'

    # Method of the form
    method = 'POST'

    # URL (not name of the url) to which this form has to be submitted.
    form_action = ''

    # Extra context dict
    extra_context_dict = None

    # A set of functions which will be executed when render function is called.
    # The form renderer will be passed as a parameter to this function
    pre_processors = [
        validation_preprocessor,
        remote_validation_preprocessor,
        extra_widget_args,
        extra_widget_class_names,
        replace_widgets
    ]

    # A list of extra templates that has to be loaded.
    # This helps pre processors to add code to template.
    extra_templates = []

    js_templates = []

    _required_js_files = []

    def __init__(self, form, request=None, form_id=None, csrf_token=None, template=None):
        self.form = form
        self.request = request
        self.csrf_token = csrf_token

        if template is not None:
            self.template = template

        if self.request is None and csrf_token is None:
            raise CSRFTokenMissingException()

        if self.pre_processors is not None:
            self.pre_processors = self.pre_processors[:]

        if self.extra_templates is None:
            self.extra_templates = []
        else:
            self.extra_templates = self.extra_templates[:]

        if self.js_templates is None:
            self.js_templates = []
        else:
            self.js_templates = self.js_templates[:]
        self.js_templates.append('form-renderer/widget-js.js')

        if form_id is not None:
            self.form_id = form_id
        self.data = None

    def __str__(self):
        return self.render()

    def __unicode__(self):
        return self.render()

    def add_js_requirement(self, files):
        t = type(files)
        if t in (tuple, list):
            for f in files:
                self._required_js_files.append(f)
        elif t in types.StringTypes:
            self._required_js_files.append(files)

    def js_files(self):
        js = self._required_js_files[:]
        for name, field in self.form.fields.items():
            widget = field.widget
            js += get_js_files(widget)
        return js

    def render_prepare(self):
        if self.form_id is None:
            raise FormIDMissingException()

        if self.data is not None:
            return

        pre_processors = self.pre_processors
        if pre_processors is not None:
            for pre_processor in pre_processors:
                if not isinstance(pre_processor, types.FunctionType):
                    pre_processor = get_function(pre_processor)

                if isinstance(pre_processor, types.FunctionType):
                    pre_processor(self)

        data = {
            'form': self.form,
            'form_submit': self.form_submit,
            'focus_first': self.focus_first,
            'form_id': self.form_id,
            'method': self.method,
            'form_action': self.form_action,
            'csrf_token_html': self.csrf_token
        }

        if type(self.extra_context_dict) is dict:
            data.update(self.extra_context_dict)

        self.data = data

    def render_templates(self, templates):
        self.render_prepare()
        data = self.data
        output = []
        for template in templates:
            output.append(render_to_string(template, data, self.request))
        return mark_safe(remove_blank_lines('\n'.join(output)))

    def render(self):
        templates = self.extra_templates[:]
        templates.insert(0, self.template)
        return self.render_templates(templates)

    def render_js(self):
        return self.render_templates(self.js_templates[:])



# coding=utf-8
from django.forms.util import flatatt
from django.utils.html import format_html
from django.utils.safestring import mark_safe


def get_class_names(class_names):
    if type(class_names) in (list, tuple):
        class_names = ' '.join(class_names)
    class_names = class_names.strip()
    while class_names.find('  ') > 0:
        class_names = class_names.replace('  ', '')
    return class_names


def generate_code(tag, attrs, text='', self_closing=False, start_only=False):
    class_names = attrs.pop('class', None)

    if class_names is not None:
        attrs['class'] = get_class_names(class_names)

    for key, val in attrs.items():
        if val is None:
            del attrs[key]

    attrs = flatatt(attrs)
    if self_closing:
        string = "<{0}{1} />"
        html = format_html(string, tag, attrs)
    elif start_only:
        string = "<{0}{1}>"
        html = format_html(string, tag, attrs)
    else:
        string = "<{0}{1}>{2}</{0}>"
        try:
            html = format_html(string, tag, attrs, text)
        except UnicodeError:
            string = "<{0}{1}>%s</{0}>"
            html = format_html(string, tag, attrs)
            html = html % text
    return mark_safe(html)


# coding=utf-8
icons = {
    'glass': 'icon-glass',
    'music': 'icon-music',
    'search': 'icon-search',
    'envelope': 'icon-envelope',
    'heart': 'icon-heart',
    'star': 'icon-star',
    'star-empty': 'icon-star-empty',
    'user': 'icon-user',
    'film': 'icon-film',
    'th-large': 'icon-th-large',
    'th': 'icon-th',
    'th-list': 'icon-th-list',
    'ok': 'icon-ok',
    'remove': 'icon-remove',
    'zoom-in': 'icon-zoom-in',
    'zoom-out': 'icon-zoom-out',
    'off': 'icon-off',
    'signal': 'icon-signal',
    'cog': 'icon-cog',
    'trash': 'icon-trash',
    'home': 'icon-home',
    'file': 'icon-file',
    'time': 'icon-time',
    'road': 'icon-road',
    'download-alt': 'icon-download-alt',
    'download': 'icon-download',
    'upload': 'icon-upload',
    'inbox': 'icon-inbox',
    'play-circle': 'icon-play-circle',
    'repeat': 'icon-repeat',
    'refresh': 'icon-refresh',
    'list-alt': 'icon-list-alt',
    'lock': 'icon-lock',
    'flag': 'icon-flag',
    'headphones': 'icon-headphones',
    'volume-off': 'icon-volume-off',
    'volume-down': 'icon-volume-down',
    'volume-up': 'icon-volume-up',
    'qrcode': 'icon-qrcode',
    'barcode': 'icon-barcode',
    'tag': 'icon-tag',
    'tags': 'icon-tags',
    'book': 'icon-book',
    'bookmark': 'icon-bookmark',
    'print': 'icon-print',
    'camera': 'icon-camera',
    'font': 'icon-font',
    'bold': 'icon-bold',
    'italic': 'icon-italic',
    'text-height': 'icon-text-height',
    'text-width': 'icon-text-width',
    'align-left': 'icon-align-left',
    'align-center': 'icon-align-center',
    'align-right': 'icon-align-right',
    'align-justify': 'icon-align-justify',
    'list': 'icon-list',
    'indent-left': 'icon-indent-left',
    'indent-right': 'icon-indent-right',
    'facetime-video': 'icon-facetime-video',
    'picture': 'icon-picture',
    'pencil': 'icon-pencil',
    'map-marker': 'icon-map-marker',
    'adjust': 'icon-adjust',
    'tint': 'icon-tint',
    'edit': 'icon-edit',
    'share': 'icon-share',
    'check': 'icon-check',
    'move': 'icon-move',
    'step-backward': 'icon-step-backward',
    'fast-backward': 'icon-fast-backward',
    'backward': 'icon-backward',
    'play': 'icon-play',
    'pause': 'icon-pause',
    'stop': 'icon-stop',
    'forward': 'icon-forward',
    'fast-forward': 'icon-fast-forward',
    'step-forward': 'icon-step-forward',
    'eject': 'icon-eject',
    'chevron-left': 'icon-chevron-left',
    'chevron-right': 'icon-chevron-right',
    'plus-sign': 'icon-plus-sign',
    'minus-sign': 'icon-minus-sign',
    'remove-sign': 'icon-remove-sign',
    'ok-sign': 'icon-ok-sign',
    'question-sign': 'icon-question-sign',
    'info-sign': 'icon-info-sign',
    'screenshot': 'icon-screenshot',
    'remove-circle': 'icon-remove-circle',
    'ok-circle': 'icon-ok-circle',
    'ban-circle': 'icon-ban-circle',
    'arrow-left': 'icon-arrow-left',
    'arrow-right': 'icon-arrow-right',
    'arrow-up': 'icon-arrow-up',
    'arrow-down': 'icon-arrow-down',
    'share-alt': 'icon-share-alt',
    'resize-full': 'icon-resize-full',
    'resize-small': 'icon-resize-small',
    'plus': 'icon-plus',
    'minus': 'icon-minus',
    'asterisk': 'icon-asterisk',
    'exclamation-sign': 'icon-exclamation-sign',
    'gift': 'icon-gift',
    'leaf': 'icon-leaf',
    'fire': 'icon-fire',
    'eye-open': 'icon-eye-open',
    'eye-close': 'icon-eye-close',
    'warning-sign': 'icon-warning-sign',
    'plane': 'icon-plane',
    'calendar': 'icon-calendar',
    'random': 'icon-random',
    'comment': 'icon-comment',
    'magnet': 'icon-magnet',
    'chevron-up': 'icon-chevron-up',
    'chevron-down': 'icon-chevron-down',
    'retweet': 'icon-retweet',
    'shopping-cart': 'icon-shopping-cart',
    'folder-close': 'icon-folder-close',
    'folder-open': 'icon-folder-open',
    'resize-vertical': 'icon-resize-vertical',
    'resize-horizontal': 'icon-resize-horizontal',
    'hdd': 'icon-hdd',
    'bullhorn': 'icon-bullhorn',
    'bell': 'icon-bell',
    'certificate': 'icon-certificate',
    'thumbs-up': 'icon-thumbs-up',
    'thumbs-down': 'icon-thumbs-down',
    'hand-right': 'icon-hand-right',
    'hand-left': 'icon-hand-left',
    'hand-up': 'icon-hand-up',
    'hand-down': 'icon-hand-down',
    'circle-arrow-right': 'icon-circle-arrow-right',
    'circle-arrow-left': 'icon-circle-arrow-left',
    'circle-arrow-up': 'icon-circle-arrow-up',
    'circle-arrow-down': 'icon-circle-arrow-down',
    'globe': 'icon-globe',
    'wrench': 'icon-wrench',
    'tasks': 'icon-tasks',
    'filter': 'icon-filter',
    'briefcase': 'icon-briefcase',
    'fullscreen': 'icon-fullscreen',
}

colors = {
    'primary': 'btn-primary',
    'info': 'btn-info',
    'success': 'btn-success',
    'warning': 'btn-warning',
    'danger': 'btn-danger',
    'inverse': 'btn-inverse',
    'link': 'btn-link',
}

sizes = {
    'large': 'btn-large',
    'small': 'btn-small',
    'mini': 'btn-mini',
}


__all__ = ('sizes', 'icons', 'colors')

def gen_colors():
    x = "btn-primary btn-info btn-success btn-warning btn-danger btn-inverse btn-link"
    print 'colors = {'
    for icon in x.split(' '):
        name = icon[4:]
        print "'" + name + "'",
        print ':',
        print "'" + icon + "',"
    print '}'


def gen_icons():
    x = "icon-glass icon-music icon-search icon-envelope icon-heart icon-star icon-star-empty icon-user icon-film icon-th-large icon-th icon-th-list icon-ok icon-remove icon-zoom-in icon-zoom-out icon-off icon-signal icon-cog icon-trash icon-home icon-file icon-time icon-road icon-download-alt icon-download icon-upload icon-inbox icon-play-circle icon-repeat icon-refresh icon-list-alt icon-lock icon-flag icon-headphones icon-volume-off icon-volume-down icon-volume-up icon-qrcode icon-barcode icon-tag icon-tags icon-book icon-bookmark icon-print icon-camera icon-font icon-bold icon-italic icon-text-height icon-text-width icon-align-left icon-align-center icon-align-right icon-align-justify icon-list icon-indent-left icon-indent-right icon-facetime-video icon-picture icon-pencil icon-map-marker icon-adjust icon-tint icon-edit icon-share icon-check icon-move icon-step-backward icon-fast-backward icon-backward icon-play icon-pause icon-stop icon-forward icon-fast-forward icon-step-forward icon-eject icon-chevron-left icon-chevron-right icon-plus-sign icon-minus-sign icon-remove-sign icon-ok-sign icon-question-sign icon-info-sign icon-screenshot icon-remove-circle icon-ok-circle icon-ban-circle icon-arrow-left icon-arrow-right icon-arrow-up icon-arrow-down icon-share-alt icon-resize-full icon-resize-small icon-plus icon-minus icon-asterisk icon-exclamation-sign icon-gift icon-leaf icon-fire icon-eye-open icon-eye-close icon-warning-sign icon-plane icon-calendar icon-random icon-comment icon-magnet icon-chevron-up icon-chevron-down icon-retweet icon-shopping-cart icon-folder-close icon-folder-open icon-resize-vertical icon-resize-horizontal icon-hdd icon-bullhorn icon-bell icon-certificate icon-thumbs-up icon-thumbs-down icon-hand-right icon-hand-left icon-hand-up icon-hand-down icon-circle-arrow-right icon-circle-arrow-left icon-circle-arrow-up icon-circle-arrow-down icon-globe icon-wrench icon-tasks icon-filter icon-briefcase icon-fullscreen"
    print 'icons = {'
    for icon in x.split(' '):
        name = icon[5:]
        print "'" + name + "'",
        print ':',
        print "'" + icon + "',"
    print '}'


if __name__ == "__main__":
    gen_colors()



# coding=utf-8
from django import template
from django_helpers.helpers.templatetags import TemplateNode, parse_args
from django_helpers.apps.nivo_slider.models import NivoSlider as NivoSliderModel
from django_helpers.apps.nivo_slider import NivoSlider

__author__ = 'ajumell'


class NivoSliderNode(TemplateNode):
    def render(self, context):
        name = self.args[0].resolve(context)
        slider_obj = NivoSliderModel.objects.get(name=name)
        slider = NivoSlider()

        for attr in dir(slider_obj):
            if not attr.startswith('__'):
                if hasattr(slider, attr):
                    val = getattr(slider_obj, attr)
                    setattr(slider, attr, val)

        slider.slider_id = slider_obj.id
        for img in slider_obj.slides():
            url = img.image.url
            caption = img.caption
            alt_text = img.alternate_text
            link = img.link
            transition = img.transition
            slider.add_image(url, caption, alt_text, link, transition)
        return unicode(slider)


register = template.Library()


@register.tag
def nivo_slider(parser, token):
    bits = token.split_contents()
    args, kwargs = parse_args(bits, parser)
    return NivoSliderNode(args, kwargs)


# coding=utf-8
__author__ = 'ajumell'
from django import forms
from ..widgets import bootstrap

GenericIPAddressField = forms.GenericIPAddressField
FilePathField = forms.FilePathField
SlugField = forms.SlugField
TypedChoiceField = forms.TypedChoiceField
TypedMultipleChoiceField = forms.TypedMultipleChoiceField
SplitDateTimeField = forms.SplitDateTimeField
ComboField = forms.ComboField
MultiValueField = forms.MultiValueField
NullBooleanField = forms.NullBooleanField
RegexField = forms.RegexField


class CharField(forms.CharField):
    pass


class PasswordField(forms.CharField):
    widget = forms.PasswordInput


class DateField(forms.DateField):
    widget = bootstrap.DatePickerWidget


class DateTimeField(forms.DateTimeField):
    widget = bootstrap.DateTimePickerWidget


class TimeField(forms.TimeField):
    widget = bootstrap.TimePickerWidget


class MultipleChoiceField(forms.MultipleChoiceField):
    widget = bootstrap.MultiSelectWidget


class ChoiceField(forms.ChoiceField):
    widget = bootstrap.SelectWidget


class BooleanField(forms.BooleanField):
    widget = bootstrap.SwitchWidget


class DecimalField(forms.DecimalField):
    pass


class URLField(forms.URLField):
    pass


class IPAddressField(forms.IPAddressField):
    pass


class ModelChoiceField(forms.ModelChoiceField):
    pass


class EmailField(forms.EmailField):
    pass


class FileField(forms.FileField):
    pass


class IntegerField(forms.IntegerField):
    pass


class FloatField(forms.FloatField):
    pass


class FileField(forms.FileField):
    pass


class ImageField(forms.ImageField):
    pass




"""
This file demonstrates writing tests using the unittest module. These will pass
when you run "manage.py test".

Replace this with more appropriate tests for your application.
"""

from django.test import TestCase
from widgets.bootstrap import DatePickerWidget


class JSFormatTestBase(TestCase):
    widget_class = None

    def test_format(self, date_format, excepted):
        widget = self.widget_class(format=date_format)
        self.assertEqual(excepted, widget.js_date_format())


class DatePickerJSFormatConvertion(JSFormatTestBase):
    widget_class = DatePickerWidget

    def test_basic_addition(self):
        self.test_format('', '')


# coding=utf-8
from datetime import datetime
from django.http import HttpResponseRedirect
from django_helpers import get_settings_val


SESSION_TIME_OUT = get_settings_val('SESSION_TIME_OUT_INTERVAL', 10 * 60)


class SessionExpiredMiddleware:
    def process_request(self, request):
        """
        @param request: The request object
        @type request: django.http.HttpRequest
        @return:
        """
        session = getattr(request, 'session', None)
        if session is None:
            return None

        last_activity = session.get('last_activity')
        now = datetime.now()
        if last_activity is not None:
            if (now - last_activity).seconds > SESSION_TIME_OUT:
                return HttpResponseRedirect("LOGIN_PAGE_URL")
        session['last_activity'] = now